"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("../fs");
const writeFileAtomic_1 = require("./writeFileAtomic");
/**
 * Writes a Javascript Object to file as JSON.
 * @function writeJson
 * @memberof fsn/nextra
 * @param {string} file The path to the file you want to create
 * @param {Object} object The javascript object you would like to write to file
 * @param {JsonOptions} [options = {}] The options to pass JSON.stringify and writeFile
 * @param {boolean} [atomic = false] Whether the operation should run atomically
 * @returns {Promise<void>}
 */
/**
 * Writes a Javascript Object to file as JSON.
 * @function writeJSON
 * @memberof fsn/nextra
 * @param {string} file The path to the file you want to create
 * @param {Object} object The javascript object you would like to write to file
 * @param {JsonOptions} [options = {}] The options to pass JSON.stringify and writeFile
 * @param {boolean} [atomic = false] Whether the operation should run atomically
 * @returns {Promise<void>}
 */
async function writeJSON(file, object, options = {}, atomic = false) {
    if (typeof options === 'boolean')
        [atomic, options] = [options, {}];
    const writeMethod = atomic ? writeFileAtomic_1.default : fs_1.writeFile;
    await writeMethod(file, `${JSON.stringify(object, options.replacer, options.spaces)}\n`, options);
}
exports.default = writeJSON;
//# sourceMappingURL=writeJSON.js.map